@@ -18,12 +18,17 @@ int  priority(int);
 
 int  last_digit(double);
 
-int  round(double);
+int  round_double_to_int(double);
 int  fact_too_large(double);
 double fact_function(double);
 double fact_function_jr(double);
 int almost_integer(double, double);
 
+double sign_of_double(double) ;
+double max_fabs(double, double); 
+double smart_sum(double, double, double);
+
+
 void error_occured(char *, int);
 void mess(char *, int);
 void messd(char *, double);
