@@ -1,7 +1,7 @@
 /*
  * Calcoo: b_accel.c
  *
- * Copyright (C) 2001,2002 Alexei Kaminski
+ * Copyright (C) 2001-2003 Alexei Kaminski
  *
  * all about the keyboard accelerators
  */
@@ -89,6 +89,22 @@ void assign_accel(void)
 	accel_button(CODE_COS, 0, GDK_c);
 	accel_button(CODE_TAN, 0, GDK_t);
 
+	accel_button(CODE_LOG, 0, GDK_g);
+	accel_button(CODE_LN, 0, GDK_n);
+
+	accel_button(CODE_ETOX, 0, GDK_x);
+	accel_button(CODE_10TOX, 0, GDK_d);
+
+	accel_button(CODE_SQR, 0, GDK_q);
+	accel_button(CODE_SQRT, 0, GDK_w);
+
+	accel_button(CODE_INVX, 0, GDK_i);
+	accel_button(CODE_PI, 0, GDK_p);
+	accel_button(CODE_FACT, 0, GDK_f);
+
+	accel_button(CODE_ARC, 0, GDK_a);
+	accel_button(CODE_HYP, 0, GDK_h);
+
 	accel_button(CODE_EQ, 0, GDK_equal);
 
 	accel_button(CODE_DOT, 0, GDK_KP_Decimal);
