@@ -194,8 +194,8 @@ void create_widgets(void)
 		      OFFSET_OF_BLOCK_0, 
 		      LEFT_FOR_DISPLAY_VERT + INTERBLOCK_SPACING, 
 		      BUTTON_SIZE, BUTTON_SIZE / 2,
-		      button_xpm, &clicked_change_angle_measure,
-		      NULL);
+		      button_xpm, &clicked_change_angle_units,
+		      "Change angle units");
 
 	create_simple_display(ANGLE_UNIT_DISPLAY_OFFSET,
 			      OFFSET_OF_BLOCK_0, 
@@ -214,13 +214,13 @@ void create_widgets(void)
 		      button_xpm, &clicked_code_info, 
 		      "About/Help");
 
-	create_button(CODE_OPTIONS,
+	create_button(CODE_SETTINGS,
 		      OFFSET_OF_BLOCK_0, 
 		      LEFT_FOR_DISPLAY_VERT + INTERBLOCK_SPACING 
 		      + BUTTON_SIZE * 2, 
 		      BUTTON_SIZE, BUTTON_SIZE,
-		      button_xpm, &clicked_code_options, 
-		      "Options");
+		      button_xpm, &clicked_code_settings, 
+		      "Settings");
 
 
 	create_copy_button(CODE_COPY,
@@ -580,12 +580,12 @@ void create_widgets(void)
 		      button_xpm, &clicked_code_left_paren, 
 		      NULL);
 
-	create_button(CODE_EXCH_XZ,
+	create_button(CODE_STACK_DOWN,
 		      OFFSET_OF_BLOCK_3 + BUTTON_SIZE,  
 		      LEFT_FOR_DISPLAY_VERT + BUTTON_SIZE * 2,  
 		      BUTTON_SIZE, BUTTON_SIZE,
-		      button_xpm, &clicked_code_exch_xz, 
-		      "Swap X and Z");
+		      button_xpm, &clicked_code_stack_down, 
+		      "Scroll stack down");
 
 	create_button(CODE_RIGHT_PAREN,
 		      OFFSET_OF_BLOCK_3 + BUTTON_SIZE * 2,  
@@ -594,12 +594,12 @@ void create_widgets(void)
 		      button_xpm, &clicked_code_right_paren, 
 		      NULL);
 
-	create_button(CODE_EXCH_XT,
+	create_button(CODE_STACK_UP,
 		      OFFSET_OF_BLOCK_3 + BUTTON_SIZE * 2,  
 		      LEFT_FOR_DISPLAY_VERT + BUTTON_SIZE * 2,  
 		      BUTTON_SIZE, BUTTON_SIZE,
-		      button_xpm, &clicked_code_exch_xt, 
-		      "Swap X and T");
+		      button_xpm, &clicked_code_stack_up, 
+		      "Scroll stack up");
 
 	create_button(CODE_CLEAR_X,
 		      OFFSET_OF_BLOCK_3 + BUTTON_SIZE * 3,  
