@@ -1,7 +1,7 @@
 /*
  * Calcoo: body.h
  *
- * Copyright (C) 2001 Alexei Kaminski
+ * Copyright (C) 2001, 2002 Alexei Kaminski
  *
  */
 
@@ -13,6 +13,9 @@
 
 #define SEPARATOR_NUMBER 10
 
+/* 
+ * display to display numbers 
+ */
 typedef struct tbd {
 	GtkWidget *minus_sign[INPUT_LENGTH];
 	GtkWidget *int_digits[INPUT_LENGTH][BASE];  
@@ -28,32 +31,55 @@ typedef struct tbd {
 } t_body_display ;
 
 
+/* 
+ * display to display few pixmaps (indicators, like deg/rad) 
+ */
 typedef struct tbsd {
 	GtkWidget *glyph[SD_G_MAX];
 	GtkWidget *frame;
+	int number_of_glyphs;
 } t_body_simple_display;
 
+
+/*
+ * the whole calculator body
+ */
 typedef struct tcb {
+/*-----------------------------*/
 	GtkWidget *main_window;
-	GtkWidget *fixer; /* the parent widget of buttons and displays, 
-			     to prevent their resizing */
+	
+	/* the parent widget of buttons and displays, 
+	 * to prevent their resizing */
+	GtkWidget *fixer; 
 
+	GtkStyle  *style;
+
+/*----- buttons and related -------------*/
 	GtkWidget *button[MAX_BUTTON_NUMBER];
-	GtkWidget *icon[MAX_BUTTON_NUMBER];
-	GtkTooltips *button_tooltips;
+	GtkWidget *deg_rad_button, *forced_e_button;
 
-	t_body_display *display[NUMBER_OF_DISPLAYS];
+	GtkWidget *icon[MAX_BUTTON_NUMBER]; /* button icons */
+
+	GtkTooltips *button_tooltips;
+	GtkAccelGroup *accel_group;
+
+/*----- displays -----------------------*/
+	/* the main display, memory displays, register displays */
+	t_body_display *display[NUMBER_OF_DISPLAYS]; 
+
+	/* deg/rad display, fix/exp/sci display, operation displays */
 	t_body_simple_display *simple_display[NUMBER_OF_SIMPLE_DISPLAYS];
 
-	GtkWidget *op_display_label[NUMBER_OF_REG_DISPLAYS];
+	/* not quite a display, just a string to hold the main display contents
+	 * used only for "copy" */
 	char char_display[INPUT_LENGTH + EXP_INPUT_LENGTH + 5];
-	GtkWidget *deg_rad_button, *forced_e_button;
-        GtkWidget *deg_rad_frame, *forced_e_frame;
-	GtkWidget *deg_icon, *rad_icon, *forced_e_icon;
-	GtkWidget *separator[SEPARATOR_NUMBER];
 
-	GtkAccelGroup *accel_group;
-	GtkStyle  *style;
+/*------ options stored in the body ------*/
+	/* (the other options are stored in the cpu, see cpu.h) 
+	 * these variables are initialized by the call to load_options()
+	 * from main.c */
+	int arc_autorelease, hyp_autorelease;
+
 } t_calcoo_body ;
 
 extern t_calcoo_body *body;
