@@ -23,7 +23,9 @@ void call_mem_op(int received_code)
 
 	switch (received_code){
 	case CODE_MEM_PLUS  :  
-		cpu->mem[cpu->curr_mem] += cpu->x;
+		cpu->mem[cpu->curr_mem] = smart_sum(cpu->x, 
+						    cpu->mem[cpu->curr_mem],
+						    cpu->precision);
 		break;
 	case CODE_MEM_TO_X  :  
 		if (cpu->rpn_mode) {
